@@ -24,6 +24,7 @@ import os
 import select
 import popen2
 import errno
+import gobject
 import gtk
 import shutil
 import re
@@ -40,11 +41,12 @@ def run_dialog( text, parent=None, messagetype=gtk.MESSAGE_WARNING, buttonstype=
     """Run a dialog with text 'text'.
        Extra buttons are passed as tuples of (button label, response id).
     """
+    escaped = gobject.markup_escape_text(text)
     d = gtk.MessageDialog(None,
         gtk.DIALOG_DESTROY_WITH_PARENT,
         messagetype,
         buttonstype,
-        '<span weight="bold" size="larger">%s</span>' % text)
+        '<span weight="bold" size="larger">%s</span>' % escaped)
     if parent:
         d.set_transient_for(parent.widget.get_toplevel())
     for b,rid in extrabuttons:
@@ -143,9 +145,9 @@ def read_pipe_iter(command, errorstream, yield_interval=0.1, workdir=None):
     class sentinel(object):
         def __del__(self):
             if self.pipe:
-                errorstream.write("killing '%s' with pid '%i'\n" % (command[0], self.pipe.pid) )
-                os.kill(self.pipe.pid,  signal.SIGTERM)
-                errorstream.write("killed (staus was '%i')\n" % (self.pipe.wait()))
+                errorstream.write("killing '%s' with pid '%i'\n" % (command[0], self.pipe.pid))
+                os.kill(self.pipe.pid, signal.SIGTERM)
+                errorstream.write("killed (status was '%i')\n" % self.pipe.wait())
         def __call__(self):
             if workdir:
                 savepwd = os.getcwd()
@@ -187,7 +189,7 @@ def write_pipe(command, text):
     pipe = popen2.Popen3(command, capturestderr=1)
     pipe.tochild.write(text)
     pipe.tochild.close()
-    pipe.wait()
+    return pipe.wait()
 
 def safe_apply(object, method, args):
     """Call 'object.method(args)' if 'object' has an attribute named 'method'.
